<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../../../lxqttaskbar.cpp" line="644"/>
        <source>Activate task %1</source>
        <translation>Aktyvuoti užduotį %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="514"/>
        <source>Application</source>
        <translation>Programa</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="548"/>
        <source>To &amp;Desktop</source>
        <translation>Į &amp;darbalaukį</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="550"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Visus darbalaukius</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="558"/>
        <source>Desktop &amp;%1</source>
        <translation>Darbalaukį &amp;%1</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="565"/>
        <source>&amp;To Current Desktop</source>
        <translation>Į &amp;esamą darbalaukį</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="573"/>
        <source>&amp;Move</source>
        <translation>&amp;Perkelti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="576"/>
        <source>Resi&amp;ze</source>
        <translation>Keisti dy&amp;dį</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="583"/>
        <source>Ma&amp;ximize</source>
        <translation>Iš&amp;skleisti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="590"/>
        <source>Maximize vertically</source>
        <translation>Išskleisti vertikaliai</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="595"/>
        <source>Maximize horizontally</source>
        <translation>Išskleisti horizontaliai</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="601"/>
        <source>&amp;Restore</source>
        <translation>&amp;Atkurti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="605"/>
        <source>Mi&amp;nimize</source>
        <translation>Sus&amp;kleisti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="611"/>
        <source>Roll down</source>
        <translation>Užraityti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="617"/>
        <source>Roll up</source>
        <translation>Nuraityti</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="625"/>
        <source>&amp;Layer</source>
        <translation>S&amp;luoksnis</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="627"/>
        <source>Always on &amp;top</source>
        <translation>Visada vi&amp;ršuje</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="633"/>
        <source>&amp;Normal</source>
        <translation>&amp;Normalus</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="639"/>
        <source>Always on &amp;bottom</source>
        <translation>Visada a&amp;pačioje</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbutton.cpp" line="647"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="83"/>
        <source>Group</source>
        <translation>Grupė</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskgroup.cpp" line="85"/>
        <source>Close group</source>
        <translation>Užverti grupę</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Užduočių tvarkytuvės nustatymai</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Rodyti tik langus iš darbalaukio</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Rodyti tik langus iš &amp;skydelio ekrano</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Rodyti tik suskleistus langus</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Suskleistus langus iškelti esamame darbalaukyje</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Užverti, spustelėjus viduriniu pelės mygtuku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="83"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Perjunginėti langus, slenkant pelės ratuku</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="93"/>
        <source>Window &amp;grouping</source>
        <translation>Langų &amp;grupavimas</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="102"/>
        <source>Show popup on mouse hover</source>
        <translation>Užvedus pelę, rodyti iškylantįjį langą</translation>
    </message>
    <message>
        <source>Show popup on mouse hover </source>
        <translation>Užvedus pelę, rodyti iškylantįjį langą </translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="121"/>
        <source>Button style</source>
        <translation>Mygtukų stilius</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="131"/>
        <source>Maximum button width</source>
        <translation>Didžiausias mygtuko plotis</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="144"/>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="170"/>
        <source> px</source>
        <translation> pikselių</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="157"/>
        <source>Maximum button height</source>
        <translation>Didžiausias mygtuko aukštis</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="183"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Automatiškai &amp;pasukti mygtukus, jei skydelis vertikalus</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.ui" line="190"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Jei prieinama, naudoti WindowClass piktogramas</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Icon and text</source>
        <translation>Piktograma ir tekstas</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only icon</source>
        <translation>Tik piktograma</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="47"/>
        <source>Only text</source>
        <translation>Tik tekstas</translation>
    </message>
    <message>
        <location filename="../../../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Current</source>
        <translation>Esamo</translation>
    </message>
</context>
</TS>
